# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Locator(Base):
	"""The Locator class encapsulates a user managed locator node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Locator property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'locator'

	def __init__(self, parent):
		super(Locator, self).__init__(parent)

	@property
	def Address(self):
		"""It gives details about the Ip

		Returns:
			str
		"""
		return self._get_attribute('address')
	@Address.setter
	def Address(self, value):
		self._set_attribute('address', value)

	@property
	def Enabled(self):
		"""It True, it enables the protocol

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Family(self):
		"""It gives details about the family

		Returns:
			str(ipv4|ipv6)
		"""
		return self._get_attribute('family')
	@Family.setter
	def Family(self, value):
		self._set_attribute('family', value)

	@property
	def LispInterfaceId(self):
		"""It gives details about the LISP interface id

		Returns:
			number
		"""
		return self._get_attribute('lispInterfaceId')
	@LispInterfaceId.setter
	def LispInterfaceId(self, value):
		self._set_attribute('lispInterfaceId', value)

	@property
	def LocalLocator(self):
		"""If True, It gives the address of the local locator

		Returns:
			bool
		"""
		return self._get_attribute('localLocator')
	@LocalLocator.setter
	def LocalLocator(self, value):
		self._set_attribute('localLocator', value)

	@property
	def MPriority(self):
		"""It denotes the m priority

		Returns:
			number
		"""
		return self._get_attribute('mPriority')
	@MPriority.setter
	def MPriority(self, value):
		self._set_attribute('mPriority', value)

	@property
	def MWeight(self):
		"""It denotes the m weight

		Returns:
			number
		"""
		return self._get_attribute('mWeight')
	@MWeight.setter
	def MWeight(self, value):
		self._set_attribute('mWeight', value)

	@property
	def Priority(self):
		"""It gives the priority

		Returns:
			number
		"""
		return self._get_attribute('priority')
	@Priority.setter
	def Priority(self, value):
		self._set_attribute('priority', value)

	@property
	def ProtocolInterfaceIpItemId(self):
		"""It gives details about the protocol interface ip item id

		Returns:
			number
		"""
		return self._get_attribute('protocolInterfaceIpItemId')
	@ProtocolInterfaceIpItemId.setter
	def ProtocolInterfaceIpItemId(self, value):
		self._set_attribute('protocolInterfaceIpItemId', value)

	@property
	def Reachability(self):
		"""If true, it defines the reachability

		Returns:
			bool
		"""
		return self._get_attribute('reachability')
	@Reachability.setter
	def Reachability(self, value):
		self._set_attribute('reachability', value)

	@property
	def Weight(self):
		"""It gives details about the weight

		Returns:
			number
		"""
		return self._get_attribute('weight')
	@Weight.setter
	def Weight(self, value):
		self._set_attribute('weight', value)

	def update(self, Address=None, Enabled=None, Family=None, LispInterfaceId=None, LocalLocator=None, MPriority=None, MWeight=None, Priority=None, ProtocolInterfaceIpItemId=None, Reachability=None, Weight=None):
		"""Updates a child instance of locator on the server.

		Args:
			Address (str): It gives details about the Ip
			Enabled (bool): It True, it enables the protocol
			Family (str(ipv4|ipv6)): It gives details about the family
			LispInterfaceId (number): It gives details about the LISP interface id
			LocalLocator (bool): If True, It gives the address of the local locator
			MPriority (number): It denotes the m priority
			MWeight (number): It denotes the m weight
			Priority (number): It gives the priority
			ProtocolInterfaceIpItemId (number): It gives details about the protocol interface ip item id
			Reachability (bool): If true, it defines the reachability
			Weight (number): It gives details about the weight

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Address=None, Enabled=None, Family=None, LispInterfaceId=None, LocalLocator=None, MPriority=None, MWeight=None, Priority=None, ProtocolInterfaceIpItemId=None, Reachability=None, Weight=None):
		"""Adds a new locator node on the server and retrieves it in this instance.

		Args:
			Address (str): It gives details about the Ip
			Enabled (bool): It True, it enables the protocol
			Family (str(ipv4|ipv6)): It gives details about the family
			LispInterfaceId (number): It gives details about the LISP interface id
			LocalLocator (bool): If True, It gives the address of the local locator
			MPriority (number): It denotes the m priority
			MWeight (number): It denotes the m weight
			Priority (number): It gives the priority
			ProtocolInterfaceIpItemId (number): It gives details about the protocol interface ip item id
			Reachability (bool): If true, it defines the reachability
			Weight (number): It gives details about the weight

		Returns:
			self: This instance with all currently retrieved locator data using find and the newly added locator data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the locator data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Address=None, Enabled=None, Family=None, LispInterfaceId=None, LocalLocator=None, MPriority=None, MWeight=None, Priority=None, ProtocolInterfaceIpItemId=None, Reachability=None, Weight=None):
		"""Finds and retrieves locator data from the server.

		All named parameters support regex and can be used to selectively retrieve locator data from the server.
		By default the find method takes no parameters and will retrieve all locator data from the server.

		Args:
			Address (str): It gives details about the Ip
			Enabled (bool): It True, it enables the protocol
			Family (str(ipv4|ipv6)): It gives details about the family
			LispInterfaceId (number): It gives details about the LISP interface id
			LocalLocator (bool): If True, It gives the address of the local locator
			MPriority (number): It denotes the m priority
			MWeight (number): It denotes the m weight
			Priority (number): It gives the priority
			ProtocolInterfaceIpItemId (number): It gives details about the protocol interface ip item id
			Reachability (bool): If true, it defines the reachability
			Weight (number): It gives details about the weight

		Returns:
			self: This instance with matching locator data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of locator data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the locator data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class RsvpP2mpEgressLsps(Base):
	"""The RsvpP2mpEgressLsps class encapsulates a required rsvpP2mpEgressLsps node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the RsvpP2mpEgressLsps property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'rsvpP2mpEgressLsps'

	def __init__(self, parent):
		super(RsvpP2mpEgressLsps, self).__init__(parent)

	@property
	def RsvpRroSubObjectsList(self):
		"""An instance of the RsvpRroSubObjectsList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.rsvprrosubobjectslist.RsvpRroSubObjectsList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.rsvprrosubobjectslist import RsvpRroSubObjectsList
		return RsvpRroSubObjectsList(self)

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DestinationIpv4GroupAddress(self):
		"""Destination IPv4 Group Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('destinationIpv4GroupAddress')

	@property
	def EnableFixedLabelForReservations(self):
		"""Enable Fixed Label For Reservations

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableFixedLabelForReservations')

	@property
	def EndPointIpv6(self):
		"""Destination IPv6 Group Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('endPointIpv6')

	@property
	def IncludeConnectedIpOnTop(self):
		"""Include connected IP on top

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeConnectedIpOnTop')

	@property
	def IncludeLeafIpAtBottom(self):
		"""Include Leaf IP at bottom

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeLeafIpAtBottom')

	@property
	def LabelValue(self):
		"""Label Value

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('labelValue')

	@property
	def LocalIp(self):
		"""Local IP

		Returns:
			list(str)
		"""
		return self._get_attribute('localIp')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NumberOfRroSubObjects(self):
		"""Number Of RRO Sub-Objects

		Returns:
			number
		"""
		return self._get_attribute('numberOfRroSubObjects')
	@NumberOfRroSubObjects.setter
	def NumberOfRroSubObjects(self, value):
		self._set_attribute('numberOfRroSubObjects', value)

	@property
	def P2mpIdAsNumber(self):
		"""P2MP ID displayed in Integer format

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('p2mpIdAsNumber')

	@property
	def P2mpIdIp(self):
		"""P2MP ID displayed in IP Address format

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('p2mpIdIp')

	@property
	def ReflectRro(self):
		"""Reflect RRO

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('reflectRro')

	@property
	def RefreshInterval(self):
		"""Refresh Interval (ms)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('refreshInterval')

	@property
	def ReservationStyle(self):
		"""Reservation Style

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('reservationStyle')

	@property
	def SendAsRro(self):
		"""Send As RRO

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendAsRro')

	@property
	def SendAsSrro(self):
		"""Send As SRRO

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendAsSrro')

	@property
	def SendReservationConfirmation(self):
		"""Send Reservation Confirmation

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendReservationConfirmation')

	@property
	def State(self):
		"""State

		Returns:
			list(str[down|none|notStarted|up])
		"""
		return self._get_attribute('state')

	@property
	def SubLspsDown(self):
		"""Sub LSPs Down

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('subLspsDown')

	@property
	def TimeoutMultiplier(self):
		"""Timeout Multiplier

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('timeoutMultiplier')

	@property
	def TypeP2mpId(self):
		"""P2MP ID Type

		Returns:
			str(iP|p2MPId)
		"""
		return self._get_attribute('typeP2mpId')
	@TypeP2mpId.setter
	def TypeP2mpId(self, value):
		self._set_attribute('typeP2mpId', value)

	def update(self, Name=None, NumberOfRroSubObjects=None, TypeP2mpId=None):
		"""Updates a child instance of rsvpP2mpEgressLsps on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfRroSubObjects (number): Number Of RRO Sub-Objects
			TypeP2mpId (str(iP|p2MPId)): P2MP ID Type

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, Active=None, DestinationIpv4GroupAddress=None, EnableFixedLabelForReservations=None, EndPointIpv6=None, IncludeConnectedIpOnTop=None, IncludeLeafIpAtBottom=None, LabelValue=None, P2mpIdAsNumber=None, P2mpIdIp=None, ReflectRro=None, RefreshInterval=None, ReservationStyle=None, SendAsRro=None, SendAsSrro=None, SendReservationConfirmation=None, SubLspsDown=None, TimeoutMultiplier=None):
		"""Base class infrastructure that gets a list of rsvpP2mpEgressLsps device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			DestinationIpv4GroupAddress (str): optional regex of destinationIpv4GroupAddress
			EnableFixedLabelForReservations (str): optional regex of enableFixedLabelForReservations
			EndPointIpv6 (str): optional regex of endPointIpv6
			IncludeConnectedIpOnTop (str): optional regex of includeConnectedIpOnTop
			IncludeLeafIpAtBottom (str): optional regex of includeLeafIpAtBottom
			LabelValue (str): optional regex of labelValue
			P2mpIdAsNumber (str): optional regex of p2mpIdAsNumber
			P2mpIdIp (str): optional regex of p2mpIdIp
			ReflectRro (str): optional regex of reflectRro
			RefreshInterval (str): optional regex of refreshInterval
			ReservationStyle (str): optional regex of reservationStyle
			SendAsRro (str): optional regex of sendAsRro
			SendAsSrro (str): optional regex of sendAsSrro
			SendReservationConfirmation (str): optional regex of sendReservationConfirmation
			SubLspsDown (str): optional regex of subLspsDown
			TimeoutMultiplier (str): optional regex of timeoutMultiplier

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GraftSubLsp(self, *args, **kwargs):
		"""Executes the graftSubLsp operation on the server.

		Activate/Enable Tunnel selected SubLsp Ranges

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		graftSubLsp()

		graftSubLsp(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		graftSubLsp(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		graftSubLsp(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('graftSubLsp', payload=payload, response_object=None)

	def PruneSubLsp(self, *args, **kwargs):
		"""Executes the pruneSubLsp operation on the server.

		Deactivate/Disable selected Tunnel SubLsp Ranges

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		pruneSubLsp()

		pruneSubLsp(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		pruneSubLsp(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		pruneSubLsp(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('pruneSubLsp', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Activate/Enable selected Tunnel Tail Ranges

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		start(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Deactivate/Disable selected Tunnel Tail Ranges

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stop(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class UmhSelectionRouteRange(Base):
	"""The UmhSelectionRouteRange class encapsulates a user managed umhSelectionRouteRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the UmhSelectionRouteRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'umhSelectionRouteRange'

	def __init__(self, parent):
		super(UmhSelectionRouteRange, self).__init__(parent)

	@property
	def AsSegment(self):
		"""An instance of the AsSegment class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.assegment.AsSegment)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.assegment import AsSegment
		return AsSegment(self)._select()

	@property
	def Cluster(self):
		"""An instance of the Cluster class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.cluster.Cluster)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.cluster import Cluster
		return Cluster(self)._select()

	@property
	def Community(self):
		"""An instance of the Community class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.community.Community)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.community import Community
		return Community(self)._select()

	@property
	def ExtendedCommunity(self):
		"""An instance of the ExtendedCommunity class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.extendedcommunity.ExtendedCommunity)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.extendedcommunity import ExtendedCommunity
		return ExtendedCommunity(self)._select()

	@property
	def Flapping(self):
		"""An instance of the Flapping class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.flapping.Flapping)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.flapping import Flapping
		return Flapping(self)._select()

	@property
	def LabelSpace(self):
		"""An instance of the LabelSpace class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.labelspace.LabelSpace)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.labelspace import LabelSpace
		return LabelSpace(self)._select()

	@property
	def AggregatorAsNumber(self):
		"""AS number associated with Aggregator ID in Aggregator attribute

		Returns:
			number
		"""
		return self._get_attribute('aggregatorAsNumber')
	@AggregatorAsNumber.setter
	def AggregatorAsNumber(self, value):
		self._set_attribute('aggregatorAsNumber', value)

	@property
	def AggregatorIdIncrementMode(self):
		"""Increment mode of aggregator ID

		Returns:
			str(fixed|increment)
		"""
		return self._get_attribute('aggregatorIdIncrementMode')
	@AggregatorIdIncrementMode.setter
	def AggregatorIdIncrementMode(self, value):
		self._set_attribute('aggregatorIdIncrementMode', value)

	@property
	def AggregatorIpAddress(self):
		"""IP address of the aggregator in Aggregator attribute

		Returns:
			str
		"""
		return self._get_attribute('aggregatorIpAddress')
	@AggregatorIpAddress.setter
	def AggregatorIpAddress(self, value):
		self._set_attribute('aggregatorIpAddress', value)

	@property
	def DistinguisherAsNumber(self):
		"""Distinguisher AS number

		Returns:
			number
		"""
		return self._get_attribute('distinguisherAsNumber')
	@DistinguisherAsNumber.setter
	def DistinguisherAsNumber(self, value):
		self._set_attribute('distinguisherAsNumber', value)

	@property
	def DistinguisherAsNumberStep(self):
		"""Increment step of Distinguisher AS number across the routes in route range

		Returns:
			number
		"""
		return self._get_attribute('distinguisherAsNumberStep')
	@DistinguisherAsNumberStep.setter
	def DistinguisherAsNumberStep(self, value):
		self._set_attribute('distinguisherAsNumberStep', value)

	@property
	def DistinguisherAsNumberStepAcrossVrfs(self):
		"""Increment step of Distinguisher AS number across the VRFs in VRF range

		Returns:
			number
		"""
		return self._get_attribute('distinguisherAsNumberStepAcrossVrfs')
	@DistinguisherAsNumberStepAcrossVrfs.setter
	def DistinguisherAsNumberStepAcrossVrfs(self, value):
		self._set_attribute('distinguisherAsNumberStepAcrossVrfs', value)

	@property
	def DistinguisherAssignedNumber(self):
		"""Distinguisher assigned number

		Returns:
			number
		"""
		return self._get_attribute('distinguisherAssignedNumber')
	@DistinguisherAssignedNumber.setter
	def DistinguisherAssignedNumber(self, value):
		self._set_attribute('distinguisherAssignedNumber', value)

	@property
	def DistinguisherAssignedNumberStep(self):
		"""Increment step of distinguisher assigned number across routes in route range

		Returns:
			number
		"""
		return self._get_attribute('distinguisherAssignedNumberStep')
	@DistinguisherAssignedNumberStep.setter
	def DistinguisherAssignedNumberStep(self, value):
		self._set_attribute('distinguisherAssignedNumberStep', value)

	@property
	def DistinguisherAssignedNumberStepAcrossVrfs(self):
		"""Increment step of distinguisher assigned number across VRFs in VRF range

		Returns:
			number
		"""
		return self._get_attribute('distinguisherAssignedNumberStepAcrossVrfs')
	@DistinguisherAssignedNumberStepAcrossVrfs.setter
	def DistinguisherAssignedNumberStepAcrossVrfs(self, value):
		self._set_attribute('distinguisherAssignedNumberStepAcrossVrfs', value)

	@property
	def DistinguisherCount(self):
		"""Number of times increment step will be used ( default = 1 )

		Returns:
			number
		"""
		return self._get_attribute('distinguisherCount')
	@DistinguisherCount.setter
	def DistinguisherCount(self, value):
		self._set_attribute('distinguisherCount', value)

	@property
	def DistinguisherCountPerVrf(self):
		"""Number of times increment step will be used per VRF

		Returns:
			number
		"""
		return self._get_attribute('distinguisherCountPerVrf')
	@DistinguisherCountPerVrf.setter
	def DistinguisherCountPerVrf(self, value):
		self._set_attribute('distinguisherCountPerVrf', value)

	@property
	def DistinguisherIpAddress(self):
		"""Distinguisher IP address

		Returns:
			str
		"""
		return self._get_attribute('distinguisherIpAddress')
	@DistinguisherIpAddress.setter
	def DistinguisherIpAddress(self, value):
		self._set_attribute('distinguisherIpAddress', value)

	@property
	def DistinguisherIpAddressStep(self):
		"""Increment step of distinguisher IP address across routes in route range

		Returns:
			str
		"""
		return self._get_attribute('distinguisherIpAddressStep')
	@DistinguisherIpAddressStep.setter
	def DistinguisherIpAddressStep(self, value):
		self._set_attribute('distinguisherIpAddressStep', value)

	@property
	def DistinguisherIpAddressStepAcrossVrfs(self):
		"""Increment step of distinguisher IP address across VRFs in VRF range

		Returns:
			str
		"""
		return self._get_attribute('distinguisherIpAddressStepAcrossVrfs')
	@DistinguisherIpAddressStepAcrossVrfs.setter
	def DistinguisherIpAddressStepAcrossVrfs(self, value):
		self._set_attribute('distinguisherIpAddressStepAcrossVrfs', value)

	@property
	def DistinguisherMode(self):
		"""Specifies which part of the route distinguisher you want to increment.

		Returns:
			str(global|local)
		"""
		return self._get_attribute('distinguisherMode')
	@DistinguisherMode.setter
	def DistinguisherMode(self, value):
		self._set_attribute('distinguisherMode', value)

	@property
	def DistinguisherStep(self):
		"""The size of the increment step to be used with the part of the route distinguisher which will be incremented. (default = 1)

		Returns:
			number
		"""
		return self._get_attribute('distinguisherStep')
	@DistinguisherStep.setter
	def DistinguisherStep(self, value):
		self._set_attribute('distinguisherStep', value)

	@property
	def DistinguisherType(self):
		"""Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.

		Returns:
			str(as|ip|asNumber2)
		"""
		return self._get_attribute('distinguisherType')
	@DistinguisherType.setter
	def DistinguisherType(self, value):
		self._set_attribute('distinguisherType', value)

	@property
	def EnableAggregator(self):
		"""Generates an AGGREGATOR attribute using the aggregatorIpAddress, aggregatorASNum, and aggregatorIDMode. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableAggregator')
	@EnableAggregator.setter
	def EnableAggregator(self, value):
		self._set_attribute('enableAggregator', value)

	@property
	def EnableAsPath(self):
		"""Enables the generation of AS Path related items.

		Returns:
			bool
		"""
		return self._get_attribute('enableAsPath')
	@EnableAsPath.setter
	def EnableAsPath(self, value):
		self._set_attribute('enableAsPath', value)

	@property
	def EnableAtomicAggregator(self):
		"""Sets the attribute bit that indicates that the router has aggregated two or more prefixes in the AGGREGATOR attribute. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableAtomicAggregator')
	@EnableAtomicAggregator.setter
	def EnableAtomicAggregator(self, value):
		self._set_attribute('enableAtomicAggregator', value)

	@property
	def EnableCluster(self):
		"""Enables the generation of the CLUSTER attribute list based on information in clusterList. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableCluster')
	@EnableCluster.setter
	def EnableCluster(self, value):
		self._set_attribute('enableCluster', value)

	@property
	def EnableCommunity(self):
		"""Enables the generation of a COMMUNITY attribute list. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableCommunity')
	@EnableCommunity.setter
	def EnableCommunity(self, value):
		self._set_attribute('enableCommunity', value)

	@property
	def EnableGenerateUniqueRoutes(self):
		"""When set to 1, each router generates a different IP address range. When not enabled, each router will advertise the route range as is.

		Returns:
			bool
		"""
		return self._get_attribute('enableGenerateUniqueRoutes')
	@EnableGenerateUniqueRoutes.setter
	def EnableGenerateUniqueRoutes(self, value):
		self._set_attribute('enableGenerateUniqueRoutes', value)

	@property
	def EnableLocalPref(self):
		"""Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableLocalPref')
	@EnableLocalPref.setter
	def EnableLocalPref(self, value):
		self._set_attribute('enableLocalPref', value)

	@property
	def EnableMed(self):
		"""Enables the generation of a MULTI EXIT DISCRIMINATOR attribute. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableMed')
	@EnableMed.setter
	def EnableMed(self, value):
		self._set_attribute('enableMed', value)

	@property
	def EnableNextHop(self):
		"""Enables the generation of a NEXT HOP attribute. (default = true)

		Returns:
			bool
		"""
		return self._get_attribute('enableNextHop')
	@EnableNextHop.setter
	def EnableNextHop(self, value):
		self._set_attribute('enableNextHop', value)

	@property
	def EnableOrigin(self):
		"""Enables the generation of an ORIGIN attribute. (default = true)

		Returns:
			bool
		"""
		return self._get_attribute('enableOrigin')
	@EnableOrigin.setter
	def EnableOrigin(self, value):
		self._set_attribute('enableOrigin', value)

	@property
	def EnableOriginator(self):
		"""Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId. (default = false)

		Returns:
			bool
		"""
		return self._get_attribute('enableOriginator')
	@EnableOriginator.setter
	def EnableOriginator(self, value):
		self._set_attribute('enableOriginator', value)

	@property
	def EnableUseTraditionalNlri(self):
		"""If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)

		Returns:
			bool
		"""
		return self._get_attribute('enableUseTraditionalNlri')
	@EnableUseTraditionalNlri.setter
	def EnableUseTraditionalNlri(self, value):
		self._set_attribute('enableUseTraditionalNlri', value)

	@property
	def Enabled(self):
		"""Enables the UMH route range.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def FirstRoute(self):
		"""First route in route range

		Returns:
			str
		"""
		return self._get_attribute('firstRoute')
	@FirstRoute.setter
	def FirstRoute(self, value):
		self._set_attribute('firstRoute', value)

	@property
	def IncludeSourceAsExtendedCommunityPresent(self):
		"""If for a given MVPN BGP is used for exchanging C-multicast routes, or if segmented

		Returns:
			bool
		"""
		return self._get_attribute('includeSourceAsExtendedCommunityPresent')
	@IncludeSourceAsExtendedCommunityPresent.setter
	def IncludeSourceAsExtendedCommunityPresent(self, value):
		self._set_attribute('includeSourceAsExtendedCommunityPresent', value)

	@property
	def IncludeVrfRouteImportExtendedCommunityPresent(self):
		"""Defines the route target extended community.

		Returns:
			bool
		"""
		return self._get_attribute('includeVrfRouteImportExtendedCommunityPresent')
	@IncludeVrfRouteImportExtendedCommunityPresent.setter
	def IncludeVrfRouteImportExtendedCommunityPresent(self, value):
		self._set_attribute('includeVrfRouteImportExtendedCommunityPresent', value)

	@property
	def IpType(self):
		"""The type of IP address in nextworkAddress.

		Returns:
			str(ipAny|ipv4|ipv6)
		"""
		return self._get_attribute('ipType')
	@IpType.setter
	def IpType(self, value):
		self._set_attribute('ipType', value)

	@property
	def LocalPref(self):
		"""The local preference value for the routes with the LOCAL PREF attribute. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('localPref')
	@LocalPref.setter
	def LocalPref(self, value):
		self._set_attribute('localPref', value)

	@property
	def MaskWidth(self):
		"""Mask width of route range

		Returns:
			number
		"""
		return self._get_attribute('maskWidth')
	@MaskWidth.setter
	def MaskWidth(self, value):
		self._set_attribute('maskWidth', value)

	@property
	def MaskWidthTo(self):
		"""mask width of last route range

		Returns:
			number
		"""
		return self._get_attribute('maskWidthTo')
	@MaskWidthTo.setter
	def MaskWidthTo(self, value):
		self._set_attribute('maskWidthTo', value)

	@property
	def Med(self):
		"""The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('med')
	@Med.setter
	def Med(self, value):
		self._set_attribute('med', value)

	@property
	def NextHopIpAddress(self):
		"""The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)

		Returns:
			str
		"""
		return self._get_attribute('nextHopIpAddress')
	@NextHopIpAddress.setter
	def NextHopIpAddress(self, value):
		self._set_attribute('nextHopIpAddress', value)

	@property
	def NextHopMode(self):
		"""Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.

		Returns:
			str(nextHopIncrement|fixed|incrementPerPrefix)
		"""
		return self._get_attribute('nextHopMode')
	@NextHopMode.setter
	def NextHopMode(self, value):
		self._set_attribute('nextHopMode', value)

	@property
	def NextHopSetMode(self):
		"""Indicates now to set the next hop IP address.

		Returns:
			str(sameAsLocalIp|setManually)
		"""
		return self._get_attribute('nextHopSetMode')
	@NextHopSetMode.setter
	def NextHopSetMode(self, value):
		self._set_attribute('nextHopSetMode', value)

	@property
	def OriginProtocol(self):
		"""An indication of where the route entry originated.

		Returns:
			str(igp|egp|incomplete)
		"""
		return self._get_attribute('originProtocol')
	@OriginProtocol.setter
	def OriginProtocol(self, value):
		self._set_attribute('originProtocol', value)

	@property
	def OriginatorId(self):
		"""The router that originated a particular route; associated with the ORIGINATOR-ID attribute. (default = 0.0.0.0)

		Returns:
			str
		"""
		return self._get_attribute('originatorId')
	@OriginatorId.setter
	def OriginatorId(self, value):
		self._set_attribute('originatorId', value)

	@property
	def PackingFrom(self):
		"""Initial number of route packed in one BGP update

		Returns:
			number
		"""
		return self._get_attribute('packingFrom')
	@PackingFrom.setter
	def PackingFrom(self, value):
		self._set_attribute('packingFrom', value)

	@property
	def PackingTo(self):
		"""Final number of routes packed in one BGP update

		Returns:
			number
		"""
		return self._get_attribute('packingTo')
	@PackingTo.setter
	def PackingTo(self, value):
		self._set_attribute('packingTo', value)

	@property
	def RouteCountPerVrfs(self):
		"""Number of route per VRF

		Returns:
			number
		"""
		return self._get_attribute('routeCountPerVrfs')
	@RouteCountPerVrfs.setter
	def RouteCountPerVrfs(self, value):
		self._set_attribute('routeCountPerVrfs', value)

	@property
	def RouteStepAcrossVrfs(self):
		"""The route increment value across VRFs.

		Returns:
			str
		"""
		return self._get_attribute('routeStepAcrossVrfs')
	@RouteStepAcrossVrfs.setter
	def RouteStepAcrossVrfs(self, value):
		self._set_attribute('routeStepAcrossVrfs', value)

	@property
	def Step(self):
		"""step

		Returns:
			number
		"""
		return self._get_attribute('step')
	@Step.setter
	def Step(self, value):
		self._set_attribute('step', value)

	def update(self, AggregatorAsNumber=None, AggregatorIdIncrementMode=None, AggregatorIpAddress=None, DistinguisherAsNumber=None, DistinguisherAsNumberStep=None, DistinguisherAsNumberStepAcrossVrfs=None, DistinguisherAssignedNumber=None, DistinguisherAssignedNumberStep=None, DistinguisherAssignedNumberStepAcrossVrfs=None, DistinguisherCount=None, DistinguisherCountPerVrf=None, DistinguisherIpAddress=None, DistinguisherIpAddressStep=None, DistinguisherIpAddressStepAcrossVrfs=None, DistinguisherMode=None, DistinguisherStep=None, DistinguisherType=None, EnableAggregator=None, EnableAsPath=None, EnableAtomicAggregator=None, EnableCluster=None, EnableCommunity=None, EnableGenerateUniqueRoutes=None, EnableLocalPref=None, EnableMed=None, EnableNextHop=None, EnableOrigin=None, EnableOriginator=None, EnableUseTraditionalNlri=None, Enabled=None, FirstRoute=None, IncludeSourceAsExtendedCommunityPresent=None, IncludeVrfRouteImportExtendedCommunityPresent=None, IpType=None, LocalPref=None, MaskWidth=None, MaskWidthTo=None, Med=None, NextHopIpAddress=None, NextHopMode=None, NextHopSetMode=None, OriginProtocol=None, OriginatorId=None, PackingFrom=None, PackingTo=None, RouteCountPerVrfs=None, RouteStepAcrossVrfs=None, Step=None):
		"""Updates a child instance of umhSelectionRouteRange on the server.

		Args:
			AggregatorAsNumber (number): AS number associated with Aggregator ID in Aggregator attribute
			AggregatorIdIncrementMode (str(fixed|increment)): Increment mode of aggregator ID
			AggregatorIpAddress (str): IP address of the aggregator in Aggregator attribute
			DistinguisherAsNumber (number): Distinguisher AS number
			DistinguisherAsNumberStep (number): Increment step of Distinguisher AS number across the routes in route range
			DistinguisherAsNumberStepAcrossVrfs (number): Increment step of Distinguisher AS number across the VRFs in VRF range
			DistinguisherAssignedNumber (number): Distinguisher assigned number
			DistinguisherAssignedNumberStep (number): Increment step of distinguisher assigned number across routes in route range
			DistinguisherAssignedNumberStepAcrossVrfs (number): Increment step of distinguisher assigned number across VRFs in VRF range
			DistinguisherCount (number): Number of times increment step will be used ( default = 1 )
			DistinguisherCountPerVrf (number): Number of times increment step will be used per VRF
			DistinguisherIpAddress (str): Distinguisher IP address
			DistinguisherIpAddressStep (str): Increment step of distinguisher IP address across routes in route range
			DistinguisherIpAddressStepAcrossVrfs (str): Increment step of distinguisher IP address across VRFs in VRF range
			DistinguisherMode (str(global|local)): Specifies which part of the route distinguisher you want to increment.
			DistinguisherStep (number): The size of the increment step to be used with the part of the route distinguisher which will be incremented. (default = 1)
			DistinguisherType (str(as|ip|asNumber2)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.
			EnableAggregator (bool): Generates an AGGREGATOR attribute using the aggregatorIpAddress, aggregatorASNum, and aggregatorIDMode. (default = false)
			EnableAsPath (bool): Enables the generation of AS Path related items.
			EnableAtomicAggregator (bool): Sets the attribute bit that indicates that the router has aggregated two or more prefixes in the AGGREGATOR attribute. (default = false)
			EnableCluster (bool): Enables the generation of the CLUSTER attribute list based on information in clusterList. (default = false)
			EnableCommunity (bool): Enables the generation of a COMMUNITY attribute list. (default = false)
			EnableGenerateUniqueRoutes (bool): When set to 1, each router generates a different IP address range. When not enabled, each router will advertise the route range as is.
			EnableLocalPref (bool): Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)
			EnableMed (bool): Enables the generation of a MULTI EXIT DISCRIMINATOR attribute. (default = false)
			EnableNextHop (bool): Enables the generation of a NEXT HOP attribute. (default = true)
			EnableOrigin (bool): Enables the generation of an ORIGIN attribute. (default = true)
			EnableOriginator (bool): Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId. (default = false)
			EnableUseTraditionalNlri (bool): If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			Enabled (bool): Enables the UMH route range.
			FirstRoute (str): First route in route range
			IncludeSourceAsExtendedCommunityPresent (bool): If for a given MVPN BGP is used for exchanging C-multicast routes, or if segmented
			IncludeVrfRouteImportExtendedCommunityPresent (bool): Defines the route target extended community.
			IpType (str(ipAny|ipv4|ipv6)): The type of IP address in nextworkAddress.
			LocalPref (number): The local preference value for the routes with the LOCAL PREF attribute. (default = 0)
			MaskWidth (number): Mask width of route range
			MaskWidthTo (number): mask width of last route range
			Med (number): The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)
			NextHopIpAddress (str): The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)
			NextHopMode (str(nextHopIncrement|fixed|incrementPerPrefix)): Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.
			NextHopSetMode (str(sameAsLocalIp|setManually)): Indicates now to set the next hop IP address.
			OriginProtocol (str(igp|egp|incomplete)): An indication of where the route entry originated.
			OriginatorId (str): The router that originated a particular route; associated with the ORIGINATOR-ID attribute. (default = 0.0.0.0)
			PackingFrom (number): Initial number of route packed in one BGP update
			PackingTo (number): Final number of routes packed in one BGP update
			RouteCountPerVrfs (number): Number of route per VRF
			RouteStepAcrossVrfs (str): The route increment value across VRFs.
			Step (number): step

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AggregatorAsNumber=None, AggregatorIdIncrementMode=None, AggregatorIpAddress=None, DistinguisherAsNumber=None, DistinguisherAsNumberStep=None, DistinguisherAsNumberStepAcrossVrfs=None, DistinguisherAssignedNumber=None, DistinguisherAssignedNumberStep=None, DistinguisherAssignedNumberStepAcrossVrfs=None, DistinguisherCount=None, DistinguisherCountPerVrf=None, DistinguisherIpAddress=None, DistinguisherIpAddressStep=None, DistinguisherIpAddressStepAcrossVrfs=None, DistinguisherMode=None, DistinguisherStep=None, DistinguisherType=None, EnableAggregator=None, EnableAsPath=None, EnableAtomicAggregator=None, EnableCluster=None, EnableCommunity=None, EnableGenerateUniqueRoutes=None, EnableLocalPref=None, EnableMed=None, EnableNextHop=None, EnableOrigin=None, EnableOriginator=None, EnableUseTraditionalNlri=None, Enabled=None, FirstRoute=None, IncludeSourceAsExtendedCommunityPresent=None, IncludeVrfRouteImportExtendedCommunityPresent=None, IpType=None, LocalPref=None, MaskWidth=None, MaskWidthTo=None, Med=None, NextHopIpAddress=None, NextHopMode=None, NextHopSetMode=None, OriginProtocol=None, OriginatorId=None, PackingFrom=None, PackingTo=None, RouteCountPerVrfs=None, RouteStepAcrossVrfs=None, Step=None):
		"""Adds a new umhSelectionRouteRange node on the server and retrieves it in this instance.

		Args:
			AggregatorAsNumber (number): AS number associated with Aggregator ID in Aggregator attribute
			AggregatorIdIncrementMode (str(fixed|increment)): Increment mode of aggregator ID
			AggregatorIpAddress (str): IP address of the aggregator in Aggregator attribute
			DistinguisherAsNumber (number): Distinguisher AS number
			DistinguisherAsNumberStep (number): Increment step of Distinguisher AS number across the routes in route range
			DistinguisherAsNumberStepAcrossVrfs (number): Increment step of Distinguisher AS number across the VRFs in VRF range
			DistinguisherAssignedNumber (number): Distinguisher assigned number
			DistinguisherAssignedNumberStep (number): Increment step of distinguisher assigned number across routes in route range
			DistinguisherAssignedNumberStepAcrossVrfs (number): Increment step of distinguisher assigned number across VRFs in VRF range
			DistinguisherCount (number): Number of times increment step will be used ( default = 1 )
			DistinguisherCountPerVrf (number): Number of times increment step will be used per VRF
			DistinguisherIpAddress (str): Distinguisher IP address
			DistinguisherIpAddressStep (str): Increment step of distinguisher IP address across routes in route range
			DistinguisherIpAddressStepAcrossVrfs (str): Increment step of distinguisher IP address across VRFs in VRF range
			DistinguisherMode (str(global|local)): Specifies which part of the route distinguisher you want to increment.
			DistinguisherStep (number): The size of the increment step to be used with the part of the route distinguisher which will be incremented. (default = 1)
			DistinguisherType (str(as|ip|asNumber2)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.
			EnableAggregator (bool): Generates an AGGREGATOR attribute using the aggregatorIpAddress, aggregatorASNum, and aggregatorIDMode. (default = false)
			EnableAsPath (bool): Enables the generation of AS Path related items.
			EnableAtomicAggregator (bool): Sets the attribute bit that indicates that the router has aggregated two or more prefixes in the AGGREGATOR attribute. (default = false)
			EnableCluster (bool): Enables the generation of the CLUSTER attribute list based on information in clusterList. (default = false)
			EnableCommunity (bool): Enables the generation of a COMMUNITY attribute list. (default = false)
			EnableGenerateUniqueRoutes (bool): When set to 1, each router generates a different IP address range. When not enabled, each router will advertise the route range as is.
			EnableLocalPref (bool): Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)
			EnableMed (bool): Enables the generation of a MULTI EXIT DISCRIMINATOR attribute. (default = false)
			EnableNextHop (bool): Enables the generation of a NEXT HOP attribute. (default = true)
			EnableOrigin (bool): Enables the generation of an ORIGIN attribute. (default = true)
			EnableOriginator (bool): Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId. (default = false)
			EnableUseTraditionalNlri (bool): If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			Enabled (bool): Enables the UMH route range.
			FirstRoute (str): First route in route range
			IncludeSourceAsExtendedCommunityPresent (bool): If for a given MVPN BGP is used for exchanging C-multicast routes, or if segmented
			IncludeVrfRouteImportExtendedCommunityPresent (bool): Defines the route target extended community.
			IpType (str(ipAny|ipv4|ipv6)): The type of IP address in nextworkAddress.
			LocalPref (number): The local preference value for the routes with the LOCAL PREF attribute. (default = 0)
			MaskWidth (number): Mask width of route range
			MaskWidthTo (number): mask width of last route range
			Med (number): The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)
			NextHopIpAddress (str): The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)
			NextHopMode (str(nextHopIncrement|fixed|incrementPerPrefix)): Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.
			NextHopSetMode (str(sameAsLocalIp|setManually)): Indicates now to set the next hop IP address.
			OriginProtocol (str(igp|egp|incomplete)): An indication of where the route entry originated.
			OriginatorId (str): The router that originated a particular route; associated with the ORIGINATOR-ID attribute. (default = 0.0.0.0)
			PackingFrom (number): Initial number of route packed in one BGP update
			PackingTo (number): Final number of routes packed in one BGP update
			RouteCountPerVrfs (number): Number of route per VRF
			RouteStepAcrossVrfs (str): The route increment value across VRFs.
			Step (number): step

		Returns:
			self: This instance with all currently retrieved umhSelectionRouteRange data using find and the newly added umhSelectionRouteRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the umhSelectionRouteRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AggregatorAsNumber=None, AggregatorIdIncrementMode=None, AggregatorIpAddress=None, DistinguisherAsNumber=None, DistinguisherAsNumberStep=None, DistinguisherAsNumberStepAcrossVrfs=None, DistinguisherAssignedNumber=None, DistinguisherAssignedNumberStep=None, DistinguisherAssignedNumberStepAcrossVrfs=None, DistinguisherCount=None, DistinguisherCountPerVrf=None, DistinguisherIpAddress=None, DistinguisherIpAddressStep=None, DistinguisherIpAddressStepAcrossVrfs=None, DistinguisherMode=None, DistinguisherStep=None, DistinguisherType=None, EnableAggregator=None, EnableAsPath=None, EnableAtomicAggregator=None, EnableCluster=None, EnableCommunity=None, EnableGenerateUniqueRoutes=None, EnableLocalPref=None, EnableMed=None, EnableNextHop=None, EnableOrigin=None, EnableOriginator=None, EnableUseTraditionalNlri=None, Enabled=None, FirstRoute=None, IncludeSourceAsExtendedCommunityPresent=None, IncludeVrfRouteImportExtendedCommunityPresent=None, IpType=None, LocalPref=None, MaskWidth=None, MaskWidthTo=None, Med=None, NextHopIpAddress=None, NextHopMode=None, NextHopSetMode=None, OriginProtocol=None, OriginatorId=None, PackingFrom=None, PackingTo=None, RouteCountPerVrfs=None, RouteStepAcrossVrfs=None, Step=None):
		"""Finds and retrieves umhSelectionRouteRange data from the server.

		All named parameters support regex and can be used to selectively retrieve umhSelectionRouteRange data from the server.
		By default the find method takes no parameters and will retrieve all umhSelectionRouteRange data from the server.

		Args:
			AggregatorAsNumber (number): AS number associated with Aggregator ID in Aggregator attribute
			AggregatorIdIncrementMode (str(fixed|increment)): Increment mode of aggregator ID
			AggregatorIpAddress (str): IP address of the aggregator in Aggregator attribute
			DistinguisherAsNumber (number): Distinguisher AS number
			DistinguisherAsNumberStep (number): Increment step of Distinguisher AS number across the routes in route range
			DistinguisherAsNumberStepAcrossVrfs (number): Increment step of Distinguisher AS number across the VRFs in VRF range
			DistinguisherAssignedNumber (number): Distinguisher assigned number
			DistinguisherAssignedNumberStep (number): Increment step of distinguisher assigned number across routes in route range
			DistinguisherAssignedNumberStepAcrossVrfs (number): Increment step of distinguisher assigned number across VRFs in VRF range
			DistinguisherCount (number): Number of times increment step will be used ( default = 1 )
			DistinguisherCountPerVrf (number): Number of times increment step will be used per VRF
			DistinguisherIpAddress (str): Distinguisher IP address
			DistinguisherIpAddressStep (str): Increment step of distinguisher IP address across routes in route range
			DistinguisherIpAddressStepAcrossVrfs (str): Increment step of distinguisher IP address across VRFs in VRF range
			DistinguisherMode (str(global|local)): Specifies which part of the route distinguisher you want to increment.
			DistinguisherStep (number): The size of the increment step to be used with the part of the route distinguisher which will be incremented. (default = 1)
			DistinguisherType (str(as|ip|asNumber2)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.
			EnableAggregator (bool): Generates an AGGREGATOR attribute using the aggregatorIpAddress, aggregatorASNum, and aggregatorIDMode. (default = false)
			EnableAsPath (bool): Enables the generation of AS Path related items.
			EnableAtomicAggregator (bool): Sets the attribute bit that indicates that the router has aggregated two or more prefixes in the AGGREGATOR attribute. (default = false)
			EnableCluster (bool): Enables the generation of the CLUSTER attribute list based on information in clusterList. (default = false)
			EnableCommunity (bool): Enables the generation of a COMMUNITY attribute list. (default = false)
			EnableGenerateUniqueRoutes (bool): When set to 1, each router generates a different IP address range. When not enabled, each router will advertise the route range as is.
			EnableLocalPref (bool): Enables the generation of a LOCAL PREF attribute based on the information in localPref. This value should be set to true only for EBGP. (default = false)
			EnableMed (bool): Enables the generation of a MULTI EXIT DISCRIMINATOR attribute. (default = false)
			EnableNextHop (bool): Enables the generation of a NEXT HOP attribute. (default = true)
			EnableOrigin (bool): Enables the generation of an ORIGIN attribute. (default = true)
			EnableOriginator (bool): Enables the generation of an ORIGINATOR-ID attribute, based on information in originatorId. (default = false)
			EnableUseTraditionalNlri (bool): If enabled, use the traditional NLRI in the UPDATE message, instead of using the MP_REACH_NLRI Multi-protocol extension to advertise the routes. (Not applicable for MPLS and MPLS VPN Route Ranges.)
			Enabled (bool): Enables the UMH route range.
			FirstRoute (str): First route in route range
			IncludeSourceAsExtendedCommunityPresent (bool): If for a given MVPN BGP is used for exchanging C-multicast routes, or if segmented
			IncludeVrfRouteImportExtendedCommunityPresent (bool): Defines the route target extended community.
			IpType (str(ipAny|ipv4|ipv6)): The type of IP address in nextworkAddress.
			LocalPref (number): The local preference value for the routes with the LOCAL PREF attribute. (default = 0)
			MaskWidth (number): Mask width of route range
			MaskWidthTo (number): mask width of last route range
			Med (number): The multi-exit discriminator value in the MULTI EXIT DISCRIMINATOR attribute. (default = 0)
			NextHopIpAddress (str): The IP address, in either IPv4 or IPv6 format of the next hop associated with the NEXT HOP attribute. (default = 0.0.0.0)
			NextHopMode (str(nextHopIncrement|fixed|incrementPerPrefix)): Indicates that the nextHopIpAddress may be incremented for each neighbor session generated for the range of neighbor addresses.
			NextHopSetMode (str(sameAsLocalIp|setManually)): Indicates now to set the next hop IP address.
			OriginProtocol (str(igp|egp|incomplete)): An indication of where the route entry originated.
			OriginatorId (str): The router that originated a particular route; associated with the ORIGINATOR-ID attribute. (default = 0.0.0.0)
			PackingFrom (number): Initial number of route packed in one BGP update
			PackingTo (number): Final number of routes packed in one BGP update
			RouteCountPerVrfs (number): Number of route per VRF
			RouteStepAcrossVrfs (str): The route increment value across VRFs.
			Step (number): step

		Returns:
			self: This instance with matching umhSelectionRouteRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of umhSelectionRouteRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the umhSelectionRouteRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Vlan(Base):
	"""The Vlan class encapsulates a required vlan node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Vlan property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'vlan'

	def __init__(self, parent):
		super(Vlan, self).__init__(parent)

	@property
	def Tpid(self):
		"""Tag Protocol Identifier / TPID (hex). The EtherType that identifies the protocol header that follows the VLAN header (tag). (Active only if VLAN has been enabled.)

		Returns:
			str
		"""
		return self._get_attribute('tpid')
	@Tpid.setter
	def Tpid(self, value):
		self._set_attribute('tpid', value)

	@property
	def VlanCount(self):
		"""The number of VLANs configured for this interface.

		Returns:
			number
		"""
		return self._get_attribute('vlanCount')
	@VlanCount.setter
	def VlanCount(self, value):
		self._set_attribute('vlanCount', value)

	@property
	def VlanEnable(self):
		"""If enabled, a VLAN can be assigned for each of the interfaces.

		Returns:
			bool
		"""
		return self._get_attribute('vlanEnable')
	@VlanEnable.setter
	def VlanEnable(self, value):
		self._set_attribute('vlanEnable', value)

	@property
	def VlanId(self):
		"""If the VLAN option is enabled for the current interface, a VLAN ID may be added to the packet, to identify the VLAN that the packet belongs to. The default is 1. If the VLAN Count is greater than 1 (for stacked VLANs), corresponding multiple entries will appear in the VLAN ID field.

		Returns:
			str
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	@property
	def VlanPriority(self):
		"""The user priority of the VLAN tag: a value from 0 through 7. The use and interpretation of this field is defined in ISO/IEC 15802-3.The default is 5.

		Returns:
			str
		"""
		return self._get_attribute('vlanPriority')
	@VlanPriority.setter
	def VlanPriority(self, value):
		self._set_attribute('vlanPriority', value)

	def update(self, Tpid=None, VlanCount=None, VlanEnable=None, VlanId=None, VlanPriority=None):
		"""Updates a child instance of vlan on the server.

		Args:
			Tpid (str): Tag Protocol Identifier / TPID (hex). The EtherType that identifies the protocol header that follows the VLAN header (tag). (Active only if VLAN has been enabled.)
			VlanCount (number): The number of VLANs configured for this interface.
			VlanEnable (bool): If enabled, a VLAN can be assigned for each of the interfaces.
			VlanId (str): If the VLAN option is enabled for the current interface, a VLAN ID may be added to the packet, to identify the VLAN that the packet belongs to. The default is 1. If the VLAN Count is greater than 1 (for stacked VLANs), corresponding multiple entries will appear in the VLAN ID field.
			VlanPriority (str): The user priority of the VLAN tag: a value from 0 through 7. The use and interpretation of this field is defined in ISO/IEC 15802-3.The default is 5.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ipv4(Base):
	"""The Ipv4 class encapsulates a user managed ipv4 node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ipv4 property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'ipv4'

	def __init__(self, parent):
		super(Ipv4, self).__init__(parent)

	@property
	def Gateway(self):
		"""The IPv4 address of the Gateway to the network, typically an interface on the DUT.

		Returns:
			str
		"""
		return self._get_attribute('gateway')
	@Gateway.setter
	def Gateway(self, value):
		self._set_attribute('gateway', value)

	@property
	def Ip(self):
		"""The 32-bit IPv4 address assigned to this unconnected interface.

		Returns:
			str
		"""
		return self._get_attribute('ip')
	@Ip.setter
	def Ip(self, value):
		self._set_attribute('ip', value)

	@property
	def MaskWidth(self):
		"""The number of bits in the mask used with the IPv4 address. The default is 24 bits.

		Returns:
			number
		"""
		return self._get_attribute('maskWidth')
	@MaskWidth.setter
	def MaskWidth(self, value):
		self._set_attribute('maskWidth', value)

	def update(self, Gateway=None, Ip=None, MaskWidth=None):
		"""Updates a child instance of ipv4 on the server.

		Args:
			Gateway (str): The IPv4 address of the Gateway to the network, typically an interface on the DUT.
			Ip (str): The 32-bit IPv4 address assigned to this unconnected interface.
			MaskWidth (number): The number of bits in the mask used with the IPv4 address. The default is 24 bits.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Gateway=None, Ip=None, MaskWidth=None):
		"""Adds a new ipv4 node on the server and retrieves it in this instance.

		Args:
			Gateway (str): The IPv4 address of the Gateway to the network, typically an interface on the DUT.
			Ip (str): The 32-bit IPv4 address assigned to this unconnected interface.
			MaskWidth (number): The number of bits in the mask used with the IPv4 address. The default is 24 bits.

		Returns:
			self: This instance with all currently retrieved ipv4 data using find and the newly added ipv4 data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the ipv4 data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Gateway=None, Ip=None, MaskWidth=None):
		"""Finds and retrieves ipv4 data from the server.

		All named parameters support regex and can be used to selectively retrieve ipv4 data from the server.
		By default the find method takes no parameters and will retrieve all ipv4 data from the server.

		Args:
			Gateway (str): The IPv4 address of the Gateway to the network, typically an interface on the DUT.
			Ip (str): The 32-bit IPv4 address assigned to this unconnected interface.
			MaskWidth (number): The number of bits in the mask used with the IPv4 address. The default is 24 bits.

		Returns:
			self: This instance with matching ipv4 data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ipv4 data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ipv4 data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Rfc8277LabelStack(Base):
	"""The Rfc8277LabelStack class encapsulates a system managed Rfc8277LabelStack node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Rfc8277LabelStack property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'Rfc8277LabelStack'

	def __init__(self, parent):
		super(Rfc8277LabelStack, self).__init__(parent)

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def MplsLabelEnd(self):
		"""MPLS Label End

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mplsLabelEnd')

	@property
	def MplsLabelStart(self):
		"""MPLS Label Start

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mplsLabelStart')

	@property
	def MplsLabelStep(self):
		"""MPLS Label Step

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mplsLabelStep')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	def update(self, Name=None):
		"""Updates a child instance of Rfc8277LabelStack on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, Name=None):
		"""Finds and retrieves Rfc8277LabelStack data from the server.

		All named parameters support regex and can be used to selectively retrieve Rfc8277LabelStack data from the server.
		By default the find method takes no parameters and will retrieve all Rfc8277LabelStack data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			self: This instance with matching Rfc8277LabelStack data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of Rfc8277LabelStack data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the Rfc8277LabelStack data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, MplsLabelEnd=None, MplsLabelStart=None, MplsLabelStep=None):
		"""Base class infrastructure that gets a list of Rfc8277LabelStack device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			MplsLabelEnd (str): optional regex of mplsLabelEnd
			MplsLabelStart (str): optional regex of mplsLabelStart
			MplsLabelStep (str): optional regex of mplsLabelStep

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Interface(Base):
	"""The Interface class encapsulates a user managed interface node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Interface property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'interface'

	def __init__(self, parent):
		super(Interface, self).__init__(parent)

	@property
	def CircuitAuthType(self):
		"""The type of Circuit Authentication to be used for this emulated ISIS router.

		Returns:
			str(none|password|md5)
		"""
		return self._get_attribute('circuitAuthType')
	@CircuitAuthType.setter
	def CircuitAuthType(self, value):
		self._set_attribute('circuitAuthType', value)

	@property
	def CircuitReceivedPasswordList(self):
		"""The Receive Password List is used only for Cleartext Password authentication. MD5 Authentication requires that both of the neighbors have the same MD5 key for the packets to be accepted.

		Returns:
			list(str)
		"""
		return self._get_attribute('circuitReceivedPasswordList')
	@CircuitReceivedPasswordList.setter
	def CircuitReceivedPasswordList(self, value):
		self._set_attribute('circuitReceivedPasswordList', value)

	@property
	def CircuitTransmitPassword(self):
		"""If circuitAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted IIHs.

		Returns:
			str
		"""
		return self._get_attribute('circuitTransmitPassword')
	@CircuitTransmitPassword.setter
	def CircuitTransmitPassword(self, value):
		self._set_attribute('circuitTransmitPassword', value)

	@property
	def ConfiguredHoldTime(self):
		"""The configured hold time for the interface. This value is only used if enableConfiguredHoldTime is set to true.

		Returns:
			number
		"""
		return self._get_attribute('configuredHoldTime')
	@ConfiguredHoldTime.setter
	def ConfiguredHoldTime(self, value):
		self._set_attribute('configuredHoldTime', value)

	@property
	def Enable3WayHandshake(self):
		"""If true, Ixia emulated point-to-point circuit will include 3-way TLV in its P2P IIH and attempt to establish the adjacency as specified in RFC 5303.

		Returns:
			bool
		"""
		return self._get_attribute('enable3WayHandshake')
	@Enable3WayHandshake.setter
	def Enable3WayHandshake(self, value):
		self._set_attribute('enable3WayHandshake', value)

	@property
	def EnableAutoAdjustArea(self):
		"""If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoAdjustArea')
	@EnableAutoAdjustArea.setter
	def EnableAutoAdjustArea(self, value):
		self._set_attribute('enableAutoAdjustArea', value)

	@property
	def EnableAutoAdjustMtu(self):
		"""If set, and a padded HELLO message is received on the interface, then the interfaces MTU will be adjusted to match the packet length of the received HELLO message.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoAdjustMtu')
	@EnableAutoAdjustMtu.setter
	def EnableAutoAdjustMtu(self, value):
		self._set_attribute('enableAutoAdjustMtu', value)

	@property
	def EnableAutoAdjustProtocolsSupported(self):
		"""If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.

		Returns:
			bool
		"""
		return self._get_attribute('enableAutoAdjustProtocolsSupported')
	@EnableAutoAdjustProtocolsSupported.setter
	def EnableAutoAdjustProtocolsSupported(self, value):
		self._set_attribute('enableAutoAdjustProtocolsSupported', value)

	@property
	def EnableBfdRegistration(self):
		"""Indicates if a BFD session is to be created to the ISIS peer IP address once the ISIS session is established. This allows ISIS to use BFD to maintain IPv4 connectivity the ISIS peer.

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdRegistration')
	@EnableBfdRegistration.setter
	def EnableBfdRegistration(self, value):
		self._set_attribute('enableBfdRegistration', value)

	@property
	def EnableConfiguredHoldTime(self):
		"""If true, enables a hold time for the created interfaces, based on the value set in the configuredHoldTime object.

		Returns:
			bool
		"""
		return self._get_attribute('enableConfiguredHoldTime')
	@EnableConfiguredHoldTime.setter
	def EnableConfiguredHoldTime(self, value):
		self._set_attribute('enableConfiguredHoldTime', value)

	@property
	def EnableConnectedToDut(self):
		"""If enabled, this ISIS interface is directly connected to the DUT.

		Returns:
			bool
		"""
		return self._get_attribute('enableConnectedToDut')
	@EnableConnectedToDut.setter
	def EnableConnectedToDut(self, value):
		self._set_attribute('enableConnectedToDut', value)

	@property
	def Enabled(self):
		"""Enables the use of this interface for the simulated router.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def ExtendedCircuitId(self):
		"""The integer value of the local circuit ID.

		Returns:
			number
		"""
		return self._get_attribute('extendedCircuitId')
	@ExtendedCircuitId.setter
	def ExtendedCircuitId(self, value):
		self._set_attribute('extendedCircuitId', value)

	@property
	def InterfaceId(self):
		"""The OSI interface ID for this interface.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)
		"""
		return self._get_attribute('interfaceId')
	@InterfaceId.setter
	def InterfaceId(self, value):
		self._set_attribute('interfaceId', value)

	@property
	def InterfaceIp(self):
		"""The IP address for this interface.

		Returns:
			str
		"""
		return self._get_attribute('interfaceIp')
	@InterfaceIp.setter
	def InterfaceIp(self, value):
		self._set_attribute('interfaceIp', value)

	@property
	def InterfaceIpMask(self):
		"""Available only when Interface Connected to DUT is disabled. The mask used with the IPv4 address for this virtual interface on the emulated ISIS router. This interface address is used to connect to virtual ISIS Network Ranges behind the Ixia-emulated ISIS router.

		Returns:
			str
		"""
		return self._get_attribute('interfaceIpMask')
	@InterfaceIpMask.setter
	def InterfaceIpMask(self, value):
		self._set_attribute('interfaceIpMask', value)

	@property
	def Ipv6MtMetric(self):
		"""This metric is same as the Interface Metric. If true, it allows you to enter data.

		Returns:
			number
		"""
		return self._get_attribute('ipv6MtMetric')
	@Ipv6MtMetric.setter
	def Ipv6MtMetric(self, value):
		self._set_attribute('ipv6MtMetric', value)

	@property
	def Level(self):
		"""The IS-IS level associated with the interface.

		Returns:
			str(level1|level2|level1Level2)
		"""
		return self._get_attribute('level')
	@Level.setter
	def Level(self, value):
		self._set_attribute('level', value)

	@property
	def Level1DeadTime(self):
		"""The dead (holding time) interval for level 1 hello messages, in seconds. If an ISIS router sending L1 hellos is not heard from within this time period, it will be considered down.

		Returns:
			number
		"""
		return self._get_attribute('level1DeadTime')
	@Level1DeadTime.setter
	def Level1DeadTime(self, value):
		self._set_attribute('level1DeadTime', value)

	@property
	def Level1HelloTime(self):
		"""The hello interval for level 1 hello messages, in seconds.

		Returns:
			number
		"""
		return self._get_attribute('level1HelloTime')
	@Level1HelloTime.setter
	def Level1HelloTime(self, value):
		self._set_attribute('level1HelloTime', value)

	@property
	def Level2DeadTime(self):
		"""The dead (holding time) interval for level 2 hello messages, in seconds. If an ISIS router sending L2 hellos is not heard from within this time period, it will be considered down.

		Returns:
			number
		"""
		return self._get_attribute('level2DeadTime')
	@Level2DeadTime.setter
	def Level2DeadTime(self, value):
		self._set_attribute('level2DeadTime', value)

	@property
	def Level2HelloTime(self):
		"""The hello interval for level 2 hello messages, in seconds.

		Returns:
			number
		"""
		return self._get_attribute('level2HelloTime')
	@Level2HelloTime.setter
	def Level2HelloTime(self, value):
		self._set_attribute('level2HelloTime', value)

	@property
	def Metric(self):
		"""The cost metric associated with the route.

		Returns:
			number
		"""
		return self._get_attribute('metric')
	@Metric.setter
	def Metric(self, value):
		self._set_attribute('metric', value)

	@property
	def NetworkType(self):
		"""Indicates the type of network attached to the interface: broadcast or point-to-point.

		Returns:
			str(pointToPoint|broadcast|pointToMultipoint)
		"""
		return self._get_attribute('networkType')
	@NetworkType.setter
	def NetworkType(self, value):
		self._set_attribute('networkType', value)

	@property
	def PriorityLevel1(self):
		"""Indicates the priority level 1.

		Returns:
			number
		"""
		return self._get_attribute('priorityLevel1')
	@PriorityLevel1.setter
	def PriorityLevel1(self, value):
		self._set_attribute('priorityLevel1', value)

	@property
	def PriorityLevel2(self):
		"""Indicates the priority level 2.

		Returns:
			number
		"""
		return self._get_attribute('priorityLevel2')
	@PriorityLevel2.setter
	def PriorityLevel2(self, value):
		self._set_attribute('priorityLevel2', value)

	@property
	def TeAdminGroup(self):
		"""The traffic engineering administrative group associated with the interface. (default = {00 00 00 00})

		Returns:
			str
		"""
		return self._get_attribute('teAdminGroup')
	@TeAdminGroup.setter
	def TeAdminGroup(self, value):
		self._set_attribute('teAdminGroup', value)

	@property
	def TeMaxBandwidth(self):
		"""For setting the maximum link bandwidth (sub-TLV 9) allowed for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('teMaxBandwidth')
	@TeMaxBandwidth.setter
	def TeMaxBandwidth(self, value):
		self._set_attribute('teMaxBandwidth', value)

	@property
	def TeMetricLevel(self):
		"""A user-defined metric for this TE path.

		Returns:
			number
		"""
		return self._get_attribute('teMetricLevel')
	@TeMetricLevel.setter
	def TeMetricLevel(self, value):
		self._set_attribute('teMetricLevel', value)

	@property
	def TeResMaxBandwidth(self):
		"""For setting the Maximum reservable link bandwidth (sub-TLV 10). It is the maximum bandwidth that can be reserved for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('teResMaxBandwidth')
	@TeResMaxBandwidth.setter
	def TeResMaxBandwidth(self, value):
		self._set_attribute('teResMaxBandwidth', value)

	@property
	def TeUnreservedBwPriority(self):
		"""The traffic engineering unreserved bandwidth for each priority to be advertised. There are eight distinct options. (default = 0.0)

		Returns:
			list(number)
		"""
		return self._get_attribute('teUnreservedBwPriority')
	@TeUnreservedBwPriority.setter
	def TeUnreservedBwPriority(self, value):
		self._set_attribute('teUnreservedBwPriority', value)

	def update(self, CircuitAuthType=None, CircuitReceivedPasswordList=None, CircuitTransmitPassword=None, ConfiguredHoldTime=None, Enable3WayHandshake=None, EnableAutoAdjustArea=None, EnableAutoAdjustMtu=None, EnableAutoAdjustProtocolsSupported=None, EnableBfdRegistration=None, EnableConfiguredHoldTime=None, EnableConnectedToDut=None, Enabled=None, ExtendedCircuitId=None, InterfaceId=None, InterfaceIp=None, InterfaceIpMask=None, Ipv6MtMetric=None, Level=None, Level1DeadTime=None, Level1HelloTime=None, Level2DeadTime=None, Level2HelloTime=None, Metric=None, NetworkType=None, PriorityLevel1=None, PriorityLevel2=None, TeAdminGroup=None, TeMaxBandwidth=None, TeMetricLevel=None, TeResMaxBandwidth=None, TeUnreservedBwPriority=None):
		"""Updates a child instance of interface on the server.

		Args:
			CircuitAuthType (str(none|password|md5)): The type of Circuit Authentication to be used for this emulated ISIS router.
			CircuitReceivedPasswordList (list(str)): The Receive Password List is used only for Cleartext Password authentication. MD5 Authentication requires that both of the neighbors have the same MD5 key for the packets to be accepted.
			CircuitTransmitPassword (str): If circuitAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted IIHs.
			ConfiguredHoldTime (number): The configured hold time for the interface. This value is only used if enableConfiguredHoldTime is set to true.
			Enable3WayHandshake (bool): If true, Ixia emulated point-to-point circuit will include 3-way TLV in its P2P IIH and attempt to establish the adjacency as specified in RFC 5303.
			EnableAutoAdjustArea (bool): If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.
			EnableAutoAdjustMtu (bool): If set, and a padded HELLO message is received on the interface, then the interfaces MTU will be adjusted to match the packet length of the received HELLO message.
			EnableAutoAdjustProtocolsSupported (bool): If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.
			EnableBfdRegistration (bool): Indicates if a BFD session is to be created to the ISIS peer IP address once the ISIS session is established. This allows ISIS to use BFD to maintain IPv4 connectivity the ISIS peer.
			EnableConfiguredHoldTime (bool): If true, enables a hold time for the created interfaces, based on the value set in the configuredHoldTime object.
			EnableConnectedToDut (bool): If enabled, this ISIS interface is directly connected to the DUT.
			Enabled (bool): Enables the use of this interface for the simulated router.
			ExtendedCircuitId (number): The integer value of the local circuit ID.
			InterfaceId (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)): The OSI interface ID for this interface.
			InterfaceIp (str): The IP address for this interface.
			InterfaceIpMask (str): Available only when Interface Connected to DUT is disabled. The mask used with the IPv4 address for this virtual interface on the emulated ISIS router. This interface address is used to connect to virtual ISIS Network Ranges behind the Ixia-emulated ISIS router.
			Ipv6MtMetric (number): This metric is same as the Interface Metric. If true, it allows you to enter data.
			Level (str(level1|level2|level1Level2)): The IS-IS level associated with the interface.
			Level1DeadTime (number): The dead (holding time) interval for level 1 hello messages, in seconds. If an ISIS router sending L1 hellos is not heard from within this time period, it will be considered down.
			Level1HelloTime (number): The hello interval for level 1 hello messages, in seconds.
			Level2DeadTime (number): The dead (holding time) interval for level 2 hello messages, in seconds. If an ISIS router sending L2 hellos is not heard from within this time period, it will be considered down.
			Level2HelloTime (number): The hello interval for level 2 hello messages, in seconds.
			Metric (number): The cost metric associated with the route.
			NetworkType (str(pointToPoint|broadcast|pointToMultipoint)): Indicates the type of network attached to the interface: broadcast or point-to-point.
			PriorityLevel1 (number): Indicates the priority level 1.
			PriorityLevel2 (number): Indicates the priority level 2.
			TeAdminGroup (str): The traffic engineering administrative group associated with the interface. (default = {00 00 00 00})
			TeMaxBandwidth (number): For setting the maximum link bandwidth (sub-TLV 9) allowed for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.
			TeMetricLevel (number): A user-defined metric for this TE path.
			TeResMaxBandwidth (number): For setting the Maximum reservable link bandwidth (sub-TLV 10). It is the maximum bandwidth that can be reserved for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.
			TeUnreservedBwPriority (list(number)): The traffic engineering unreserved bandwidth for each priority to be advertised. There are eight distinct options. (default = 0.0)

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, CircuitAuthType=None, CircuitReceivedPasswordList=None, CircuitTransmitPassword=None, ConfiguredHoldTime=None, Enable3WayHandshake=None, EnableAutoAdjustArea=None, EnableAutoAdjustMtu=None, EnableAutoAdjustProtocolsSupported=None, EnableBfdRegistration=None, EnableConfiguredHoldTime=None, EnableConnectedToDut=None, Enabled=None, ExtendedCircuitId=None, InterfaceId=None, InterfaceIp=None, InterfaceIpMask=None, Ipv6MtMetric=None, Level=None, Level1DeadTime=None, Level1HelloTime=None, Level2DeadTime=None, Level2HelloTime=None, Metric=None, NetworkType=None, PriorityLevel1=None, PriorityLevel2=None, TeAdminGroup=None, TeMaxBandwidth=None, TeMetricLevel=None, TeResMaxBandwidth=None, TeUnreservedBwPriority=None):
		"""Adds a new interface node on the server and retrieves it in this instance.

		Args:
			CircuitAuthType (str(none|password|md5)): The type of Circuit Authentication to be used for this emulated ISIS router.
			CircuitReceivedPasswordList (list(str)): The Receive Password List is used only for Cleartext Password authentication. MD5 Authentication requires that both of the neighbors have the same MD5 key for the packets to be accepted.
			CircuitTransmitPassword (str): If circuitAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted IIHs.
			ConfiguredHoldTime (number): The configured hold time for the interface. This value is only used if enableConfiguredHoldTime is set to true.
			Enable3WayHandshake (bool): If true, Ixia emulated point-to-point circuit will include 3-way TLV in its P2P IIH and attempt to establish the adjacency as specified in RFC 5303.
			EnableAutoAdjustArea (bool): If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.
			EnableAutoAdjustMtu (bool): If set, and a padded HELLO message is received on the interface, then the interfaces MTU will be adjusted to match the packet length of the received HELLO message.
			EnableAutoAdjustProtocolsSupported (bool): If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.
			EnableBfdRegistration (bool): Indicates if a BFD session is to be created to the ISIS peer IP address once the ISIS session is established. This allows ISIS to use BFD to maintain IPv4 connectivity the ISIS peer.
			EnableConfiguredHoldTime (bool): If true, enables a hold time for the created interfaces, based on the value set in the configuredHoldTime object.
			EnableConnectedToDut (bool): If enabled, this ISIS interface is directly connected to the DUT.
			Enabled (bool): Enables the use of this interface for the simulated router.
			ExtendedCircuitId (number): The integer value of the local circuit ID.
			InterfaceId (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)): The OSI interface ID for this interface.
			InterfaceIp (str): The IP address for this interface.
			InterfaceIpMask (str): Available only when Interface Connected to DUT is disabled. The mask used with the IPv4 address for this virtual interface on the emulated ISIS router. This interface address is used to connect to virtual ISIS Network Ranges behind the Ixia-emulated ISIS router.
			Ipv6MtMetric (number): This metric is same as the Interface Metric. If true, it allows you to enter data.
			Level (str(level1|level2|level1Level2)): The IS-IS level associated with the interface.
			Level1DeadTime (number): The dead (holding time) interval for level 1 hello messages, in seconds. If an ISIS router sending L1 hellos is not heard from within this time period, it will be considered down.
			Level1HelloTime (number): The hello interval for level 1 hello messages, in seconds.
			Level2DeadTime (number): The dead (holding time) interval for level 2 hello messages, in seconds. If an ISIS router sending L2 hellos is not heard from within this time period, it will be considered down.
			Level2HelloTime (number): The hello interval for level 2 hello messages, in seconds.
			Metric (number): The cost metric associated with the route.
			NetworkType (str(pointToPoint|broadcast|pointToMultipoint)): Indicates the type of network attached to the interface: broadcast or point-to-point.
			PriorityLevel1 (number): Indicates the priority level 1.
			PriorityLevel2 (number): Indicates the priority level 2.
			TeAdminGroup (str): The traffic engineering administrative group associated with the interface. (default = {00 00 00 00})
			TeMaxBandwidth (number): For setting the maximum link bandwidth (sub-TLV 9) allowed for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.
			TeMetricLevel (number): A user-defined metric for this TE path.
			TeResMaxBandwidth (number): For setting the Maximum reservable link bandwidth (sub-TLV 10). It is the maximum bandwidth that can be reserved for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.
			TeUnreservedBwPriority (list(number)): The traffic engineering unreserved bandwidth for each priority to be advertised. There are eight distinct options. (default = 0.0)

		Returns:
			self: This instance with all currently retrieved interface data using find and the newly added interface data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the interface data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, CircuitAuthType=None, CircuitReceivedPasswordList=None, CircuitTransmitPassword=None, ConfiguredHoldTime=None, Enable3WayHandshake=None, EnableAutoAdjustArea=None, EnableAutoAdjustMtu=None, EnableAutoAdjustProtocolsSupported=None, EnableBfdRegistration=None, EnableConfiguredHoldTime=None, EnableConnectedToDut=None, Enabled=None, ExtendedCircuitId=None, InterfaceId=None, InterfaceIp=None, InterfaceIpMask=None, Ipv6MtMetric=None, Level=None, Level1DeadTime=None, Level1HelloTime=None, Level2DeadTime=None, Level2HelloTime=None, Metric=None, NetworkType=None, PriorityLevel1=None, PriorityLevel2=None, TeAdminGroup=None, TeMaxBandwidth=None, TeMetricLevel=None, TeResMaxBandwidth=None, TeUnreservedBwPriority=None):
		"""Finds and retrieves interface data from the server.

		All named parameters support regex and can be used to selectively retrieve interface data from the server.
		By default the find method takes no parameters and will retrieve all interface data from the server.

		Args:
			CircuitAuthType (str(none|password|md5)): The type of Circuit Authentication to be used for this emulated ISIS router.
			CircuitReceivedPasswordList (list(str)): The Receive Password List is used only for Cleartext Password authentication. MD5 Authentication requires that both of the neighbors have the same MD5 key for the packets to be accepted.
			CircuitTransmitPassword (str): If circuitAuthType is isisAuthTypePassword, then this is the password (or MD5Key) that will be sent with transmitted IIHs.
			ConfiguredHoldTime (number): The configured hold time for the interface. This value is only used if enableConfiguredHoldTime is set to true.
			Enable3WayHandshake (bool): If true, Ixia emulated point-to-point circuit will include 3-way TLV in its P2P IIH and attempt to establish the adjacency as specified in RFC 5303.
			EnableAutoAdjustArea (bool): If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.
			EnableAutoAdjustMtu (bool): If set, and a padded HELLO message is received on the interface, then the interfaces MTU will be adjusted to match the packet length of the received HELLO message.
			EnableAutoAdjustProtocolsSupported (bool): If set, and a HELLO message is received which contains a protocols TLV, then the interfaces protocols will be adjusted to match the received TLV.
			EnableBfdRegistration (bool): Indicates if a BFD session is to be created to the ISIS peer IP address once the ISIS session is established. This allows ISIS to use BFD to maintain IPv4 connectivity the ISIS peer.
			EnableConfiguredHoldTime (bool): If true, enables a hold time for the created interfaces, based on the value set in the configuredHoldTime object.
			EnableConnectedToDut (bool): If enabled, this ISIS interface is directly connected to the DUT.
			Enabled (bool): Enables the use of this interface for the simulated router.
			ExtendedCircuitId (number): The integer value of the local circuit ID.
			InterfaceId (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)): The OSI interface ID for this interface.
			InterfaceIp (str): The IP address for this interface.
			InterfaceIpMask (str): Available only when Interface Connected to DUT is disabled. The mask used with the IPv4 address for this virtual interface on the emulated ISIS router. This interface address is used to connect to virtual ISIS Network Ranges behind the Ixia-emulated ISIS router.
			Ipv6MtMetric (number): This metric is same as the Interface Metric. If true, it allows you to enter data.
			Level (str(level1|level2|level1Level2)): The IS-IS level associated with the interface.
			Level1DeadTime (number): The dead (holding time) interval for level 1 hello messages, in seconds. If an ISIS router sending L1 hellos is not heard from within this time period, it will be considered down.
			Level1HelloTime (number): The hello interval for level 1 hello messages, in seconds.
			Level2DeadTime (number): The dead (holding time) interval for level 2 hello messages, in seconds. If an ISIS router sending L2 hellos is not heard from within this time period, it will be considered down.
			Level2HelloTime (number): The hello interval for level 2 hello messages, in seconds.
			Metric (number): The cost metric associated with the route.
			NetworkType (str(pointToPoint|broadcast|pointToMultipoint)): Indicates the type of network attached to the interface: broadcast or point-to-point.
			PriorityLevel1 (number): Indicates the priority level 1.
			PriorityLevel2 (number): Indicates the priority level 2.
			TeAdminGroup (str): The traffic engineering administrative group associated with the interface. (default = {00 00 00 00})
			TeMaxBandwidth (number): For setting the maximum link bandwidth (sub-TLV 9) allowed for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.
			TeMetricLevel (number): A user-defined metric for this TE path.
			TeResMaxBandwidth (number): For setting the Maximum reservable link bandwidth (sub-TLV 10). It is the maximum bandwidth that can be reserved for this link in this direction. It is a 32-bit IEEE floating point value, in bytes/sec. The default is 0.
			TeUnreservedBwPriority (list(number)): The traffic engineering unreserved bandwidth for each priority to be advertised. There are eight distinct options. (default = 0.0)

		Returns:
			self: This instance with matching interface data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of interface data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the interface data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Data(Base):
	"""The Data class encapsulates a required data node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Data property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'data'

	def __init__(self, parent):
		super(Data, self).__init__(parent)

	@property
	def Egress(self):
		"""An instance of the Egress class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.data.egress.egress.Egress)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.data.egress.egress import Egress
		return Egress(self)

	@property
	def EgressRxCondition(self):
		"""An instance of the EgressRxCondition class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.data.egressrxcondition.egressrxcondition.EgressRxCondition)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.data.egressrxcondition.egressrxcondition import EgressRxCondition
		return EgressRxCondition(self)._select()

	@property
	def AllowPaging(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('allowPaging')

	@property
	def ColumnCaptions(self):
		"""

		Returns:
			list(str)
		"""
		return self._get_attribute('columnCaptions')

	@property
	def ColumnCount(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('columnCount')

	@property
	def CurrentPage(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('currentPage')
	@CurrentPage.setter
	def CurrentPage(self, value):
		self._set_attribute('currentPage', value)

	@property
	def EgressMode(self):
		"""

		Returns:
			str(conditional|paged)
		"""
		return self._get_attribute('egressMode')
	@EgressMode.setter
	def EgressMode(self, value):
		self._set_attribute('egressMode', value)

	@property
	def EgressPageSize(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('egressPageSize')
	@EgressPageSize.setter
	def EgressPageSize(self, value):
		self._set_attribute('egressPageSize', value)

	@property
	def IsBlocked(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('isBlocked')

	@property
	def IsReady(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('isReady')

	@property
	def PageSize(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('pageSize')
	@PageSize.setter
	def PageSize(self, value):
		self._set_attribute('pageSize', value)

	@property
	def PageValues(self):
		"""Returns the values in the current page. The ingress row is grouped with its corresponding egress rows

		Returns:
			list(list[list[str]])
		"""
		return self._get_attribute('pageValues')

	@property
	def RowCount(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('rowCount')

	@property
	def RowValues(self):
		"""DEPRECATED 

		Returns:
			dict(arg1:list[list[list[str]]])
		"""
		return self._get_attribute('rowValues')

	@property
	def Timestamp(self):
		"""DEPRECATED 

		Returns:
			number
		"""
		return self._get_attribute('timestamp')

	@property
	def TotalPages(self):
		"""DEPRECATED 

		Returns:
			number
		"""
		return self._get_attribute('totalPages')

	@property
	def TotalRows(self):
		"""DEPRECATED 

		Returns:
			number
		"""
		return self._get_attribute('totalRows')

	def update(self, CurrentPage=None, EgressMode=None, EgressPageSize=None, PageSize=None):
		"""Updates a child instance of data on the server.

		Args:
			CurrentPage (number): 
			EgressMode (str(conditional|paged)): 
			EgressPageSize (number): 
			PageSize (number): 

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PortStatLearnedInformation(Base):
	"""The PortStatLearnedInformation class encapsulates a system managed portStatLearnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PortStatLearnedInformation property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'portStatLearnedInformation'

	def __init__(self, parent):
		super(PortStatLearnedInformation, self).__init__(parent)

	@property
	def Collisions(self):
		"""Indicates the number of collisions.

		Returns:
			str
		"""
		return self._get_attribute('collisions')

	@property
	def CrcErrors(self):
		"""Signifies the number of CRC errors.

		Returns:
			str
		"""
		return self._get_attribute('crcErrors')

	@property
	def DataPathId(self):
		"""Signifies the datapath ID of the OpenFlow switch.

		Returns:
			str
		"""
		return self._get_attribute('dataPathId')

	@property
	def DataPathIdAsHex(self):
		"""Signifies the datapath ID of the OpenFlow switch in hexadecimal format.

		Returns:
			str
		"""
		return self._get_attribute('dataPathIdAsHex')

	@property
	def Duration(self):
		"""The time in seconds, for which the port has been alive.

		Returns:
			number
		"""
		return self._get_attribute('duration')

	@property
	def DurationInNsec(self):
		"""The time in nanoseconds, for which the port has been alive beyond Duration (sec).

		Returns:
			number
		"""
		return self._get_attribute('durationInNsec')

	@property
	def ErrorCode(self):
		"""Signifies the error code of the error received.

		Returns:
			str
		"""
		return self._get_attribute('errorCode')

	@property
	def ErrorType(self):
		"""Signifies the type of the error received.

		Returns:
			str
		"""
		return self._get_attribute('errorType')

	@property
	def FrameAlignmentErrors(self):
		"""Signifies the number of Frame Alignment errors.

		Returns:
			str
		"""
		return self._get_attribute('frameAlignmentErrors')

	@property
	def Latency(self):
		"""Signifies the latency measurement for the OpenFlow channel in microseconds.

		Returns:
			number
		"""
		return self._get_attribute('latency')

	@property
	def LocalIp(self):
		"""Signifies the local IP address of the selected interface.

		Returns:
			str
		"""
		return self._get_attribute('localIp')

	@property
	def NegotiatedVersion(self):
		"""Version of the protocol that has been negotiated between OpenFLow Controller and Switch.

		Returns:
			str
		"""
		return self._get_attribute('negotiatedVersion')

	@property
	def PacketsDroppedByRx(self):
		"""Signifies the number of packets dropped by the receiving port.

		Returns:
			str
		"""
		return self._get_attribute('packetsDroppedByRx')

	@property
	def PacketsDroppedByTx(self):
		"""Signifies the number of packets dropped by the transmitting port.

		Returns:
			str
		"""
		return self._get_attribute('packetsDroppedByTx')

	@property
	def PacketsWithRxOverrun(self):
		"""Signifies the number of packets with received overruns.

		Returns:
			str
		"""
		return self._get_attribute('packetsWithRxOverrun')

	@property
	def PortNo(self):
		"""Signifies the port number used.

		Returns:
			number
		"""
		return self._get_attribute('portNo')

	@property
	def ReceivedBytes(self):
		"""Signifies the number of bytes received.

		Returns:
			str
		"""
		return self._get_attribute('receivedBytes')

	@property
	def ReceivedErrors(self):
		"""Signifies the number of received errors.

		Returns:
			str
		"""
		return self._get_attribute('receivedErrors')

	@property
	def ReceivedPackets(self):
		"""Signifies the number of packets received.

		Returns:
			str
		"""
		return self._get_attribute('receivedPackets')

	@property
	def RemoteIp(self):
		"""Signifies the Remote IP address of the selected interface.

		Returns:
			str
		"""
		return self._get_attribute('remoteIp')

	@property
	def ReplyState(self):
		"""Signifies the reply state of the OF Channel.

		Returns:
			str
		"""
		return self._get_attribute('replyState')

	@property
	def TransmitErrors(self):
		"""Signifies the number of Transmit errors.

		Returns:
			str
		"""
		return self._get_attribute('transmitErrors')

	@property
	def TransmittedBytes(self):
		"""Signifies the number of bytes transmitted.

		Returns:
			str
		"""
		return self._get_attribute('transmittedBytes')

	@property
	def TransmittedPackets(self):
		"""Signifies the number of packets transmitted.

		Returns:
			str
		"""
		return self._get_attribute('transmittedPackets')

	def find(self, Collisions=None, CrcErrors=None, DataPathId=None, DataPathIdAsHex=None, Duration=None, DurationInNsec=None, ErrorCode=None, ErrorType=None, FrameAlignmentErrors=None, Latency=None, LocalIp=None, NegotiatedVersion=None, PacketsDroppedByRx=None, PacketsDroppedByTx=None, PacketsWithRxOverrun=None, PortNo=None, ReceivedBytes=None, ReceivedErrors=None, ReceivedPackets=None, RemoteIp=None, ReplyState=None, TransmitErrors=None, TransmittedBytes=None, TransmittedPackets=None):
		"""Finds and retrieves portStatLearnedInformation data from the server.

		All named parameters support regex and can be used to selectively retrieve portStatLearnedInformation data from the server.
		By default the find method takes no parameters and will retrieve all portStatLearnedInformation data from the server.

		Args:
			Collisions (str): Indicates the number of collisions.
			CrcErrors (str): Signifies the number of CRC errors.
			DataPathId (str): Signifies the datapath ID of the OpenFlow switch.
			DataPathIdAsHex (str): Signifies the datapath ID of the OpenFlow switch in hexadecimal format.
			Duration (number): The time in seconds, for which the port has been alive.
			DurationInNsec (number): The time in nanoseconds, for which the port has been alive beyond Duration (sec).
			ErrorCode (str): Signifies the error code of the error received.
			ErrorType (str): Signifies the type of the error received.
			FrameAlignmentErrors (str): Signifies the number of Frame Alignment errors.
			Latency (number): Signifies the latency measurement for the OpenFlow channel in microseconds.
			LocalIp (str): Signifies the local IP address of the selected interface.
			NegotiatedVersion (str): Version of the protocol that has been negotiated between OpenFLow Controller and Switch.
			PacketsDroppedByRx (str): Signifies the number of packets dropped by the receiving port.
			PacketsDroppedByTx (str): Signifies the number of packets dropped by the transmitting port.
			PacketsWithRxOverrun (str): Signifies the number of packets with received overruns.
			PortNo (number): Signifies the port number used.
			ReceivedBytes (str): Signifies the number of bytes received.
			ReceivedErrors (str): Signifies the number of received errors.
			ReceivedPackets (str): Signifies the number of packets received.
			RemoteIp (str): Signifies the Remote IP address of the selected interface.
			ReplyState (str): Signifies the reply state of the OF Channel.
			TransmitErrors (str): Signifies the number of Transmit errors.
			TransmittedBytes (str): Signifies the number of bytes transmitted.
			TransmittedPackets (str): Signifies the number of packets transmitted.

		Returns:
			self: This instance with matching portStatLearnedInformation data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of portStatLearnedInformation data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the portStatLearnedInformation data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



"""Demonstrates file handling.

The Files object determines how file content is uploaded.
Prior to an operation if local_file=True is specified the content will be pushed to the server 
if the content exists locally.
If the file does not exist locally an empty file using only the file name will be created on the server. 

"""

from ixnetwork_restpy.testplatform.testplatform import TestPlatform
from ixnetwork_restpy.files import Files


# connect to a test platform, create a session and get the root IxNetwork object
test_platform = TestPlatform('127.0.0.1', rest_port=11009)
test_platform.Trace = 'request_response'
sessions = test_platform.Sessions.find(Id=1)
ixnetwork = sessions.Ixnetwork

# create an empty configuration on the server
ixnetwork.NewConfig()

# add 4 vport objects
ixnetwork.Vport.add().add().add().add()

# save the configuration on the server
ixnetwork.SaveConfig(Files('sample.ixncfg'))

# create an empty configuration
ixnetwork.NewConfig()
assert(len(ixnetwork.Vport.find()) == 0)

# load the saved configuration
ixnetwork.LoadConfig(Files('sample.ixncfg'))

# verify that the vport objects exist
assert(len(ixnetwork.Vport.find()) == 4)


